@@ -1,5 +1,6 @@
 /*
  * Copyright 2012-2016 Canonical Ltd.
+ * Copyright 2022 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -15,6 +16,7 @@
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
+ *   Robert Tari <robert@tari.in>
  */
 
 #include "device.h"
@@ -22,7 +24,7 @@
 
 #include <gio/gio.h>
 #include <gtest/gtest.h>
-
+#include <array>
 #include <algorithm>
 #include <cmath> // ceil()
 #include <string>
@@ -69,7 +71,7 @@ class DeviceTest : public ::testing::Test
     static std::string get_icon_names_from_device(const IndicatorPowerDevice* device)
     {
       std::string ret;
-      char ** names = indicator_power_device_get_icon_names (device);
+      char ** names = indicator_power_device_get_icon_names (device, TRUE);
       char * str = g_strjoinv (";", names);
       if (str != nullptr)
         ret = str;
@@ -280,19 +282,19 @@ TEST_F(DeviceTest, IconNames)
 
   // bad arguments
   log_count_ipower_expected++;
-  ASSERT_TRUE (indicator_power_device_get_icon_names (NULL) == NULL);
+  ASSERT_TRUE (indicator_power_device_get_icon_names (NULL, TRUE) == NULL);
 
   // power
   g_object_set (o, INDICATOR_POWER_DEVICE_KIND, UP_DEVICE_KIND_LINE_POWER,
                    NULL);
-  EXPECT_ICON_NAMES_EQ("ac-adapter-symbolic;"
+  EXPECT_ICON_NAMES_EQ("ac-adapter-panel;"
                        "ac-adapter",
                        device);
 
   // monitor
   g_object_set (o, INDICATOR_POWER_DEVICE_KIND, UP_DEVICE_KIND_MONITOR,
                    NULL);
-  EXPECT_ICON_NAMES_EQ("gpm-monitor-symbolic;"
+  EXPECT_ICON_NAMES_EQ("gpm-monitor-panel;"
                        "gpm-monitor",
                        device);
 
@@ -318,7 +320,7 @@ TEST_F(DeviceTest, IconNames)
       g_object_set (o, INDICATOR_POWER_DEVICE_KIND, kind,
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_EMPTY,
                        NULL);
-      g_string_append_printf (expected, "%s-empty-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-empty-panel;", kind_str);
       g_string_append_printf (expected, "gpm-%s-empty;", kind_str);
       g_string_append_printf (expected, "gpm-%s-000;", kind_str);
       g_string_append_printf (expected, "%s-empty", kind_str);
@@ -329,8 +331,7 @@ TEST_F(DeviceTest, IconNames)
       g_object_set (o, INDICATOR_POWER_DEVICE_KIND, kind,
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_FULLY_CHARGED,
                        NULL);
-      g_string_append_printf (expected, "%s-full-charged-symbolic;", kind_str);
-      g_string_append_printf (expected, "%s-full-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-charged-panel;", kind_str);
       g_string_append_printf (expected, "gpm-%s-full;", kind_str);
       g_string_append_printf (expected, "gpm-%s-100;", kind_str);
       g_string_append_printf (expected, "%s-full-charged;", kind_str);
@@ -343,13 +344,15 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_CHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 95.0,
                        NULL);
+      g_string_append_printf (expected, "%s-100-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-100-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-100-charging;", kind_str);
-      g_string_append_printf (expected, "%s-full-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-full-charging;", kind_str);
+      g_string_append_printf (expected, "%s-100-panel;", kind_str);
       g_string_append_printf (expected, "%s-100;", kind_str);
       g_string_append_printf (expected, "gpm-%s-100;", kind_str);
-      g_string_append_printf (expected, "%s-full-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-panel;", kind_str);
       g_string_append_printf (expected, "%s-full", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -359,17 +362,21 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_CHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 85.0,
                        NULL);
+      g_string_append_printf (expected, "%s-090-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-090-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-090-charging;", kind_str);
+      g_string_append_printf (expected, "%s-080-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-080-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-080-charging;", kind_str);
-      g_string_append_printf (expected, "%s-full-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-full-charging;", kind_str);
+      g_string_append_printf (expected, "%s-090-panel;", kind_str);
       g_string_append_printf (expected, "%s-090;", kind_str);
       g_string_append_printf (expected, "gpm-%s-090;", kind_str);
+      g_string_append_printf (expected, "%s-080-panel;", kind_str);
       g_string_append_printf (expected, "%s-080;", kind_str);
       g_string_append_printf (expected, "gpm-%s-080;", kind_str);
-      g_string_append_printf (expected, "%s-full-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-panel;", kind_str);
       g_string_append_printf (expected, "%s-full", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -379,17 +386,21 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_CHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 50.0,
                        NULL);
+      g_string_append_printf (expected, "%s-050-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-050-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-050-charging;", kind_str);
+      g_string_append_printf (expected, "%s-060-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-060-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-060-charging;", kind_str);
-      g_string_append_printf (expected, "%s-good-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-good-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-good-charging;", kind_str);
+      g_string_append_printf (expected, "%s-050-panel;", kind_str);
       g_string_append_printf (expected, "%s-050;", kind_str);
       g_string_append_printf (expected, "gpm-%s-050;", kind_str);
+      g_string_append_printf (expected, "%s-060-panel;", kind_str);
       g_string_append_printf (expected, "%s-060;", kind_str);
       g_string_append_printf (expected, "gpm-%s-060;", kind_str);
-      g_string_append_printf (expected, "%s-good-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-good-panel;", kind_str);
       g_string_append_printf (expected, "%s-good", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -399,17 +410,21 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_CHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 25.0,
                        NULL);
+      g_string_append_printf (expected, "%s-030-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-030-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-030-charging;", kind_str);
+      g_string_append_printf (expected, "%s-040-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-040-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-040-charging;", kind_str);
-      g_string_append_printf (expected, "%s-low-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-low-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-low-charging;", kind_str);
+      g_string_append_printf (expected, "%s-030-panel;", kind_str);
       g_string_append_printf (expected, "%s-030;", kind_str);
       g_string_append_printf (expected, "gpm-%s-030;", kind_str);
+      g_string_append_printf (expected, "%s-040-panel;", kind_str);
       g_string_append_printf (expected, "%s-040;", kind_str);
       g_string_append_printf (expected, "gpm-%s-040;", kind_str);
-      g_string_append_printf (expected, "%s-low-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-low-panel;", kind_str);
       g_string_append_printf (expected, "%s-low", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -419,17 +434,21 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_CHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 5.0,
                        NULL);
+      g_string_append_printf (expected, "%s-010-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-010-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-010-charging;", kind_str);
+      g_string_append_printf (expected, "%s-000-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-000-charging;", kind_str);
       g_string_append_printf (expected, "gpm-%s-000-charging;", kind_str);
-      g_string_append_printf (expected, "%s-caution-charging-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-caution-charging-panel;", kind_str);
       g_string_append_printf (expected, "%s-caution-charging;", kind_str);
+      g_string_append_printf (expected, "%s-010-panel;", kind_str);
       g_string_append_printf (expected, "%s-010;", kind_str);
       g_string_append_printf (expected, "gpm-%s-010;", kind_str);
+      g_string_append_printf (expected, "%s-000-panel;", kind_str);
       g_string_append_printf (expected, "%s-000;", kind_str);
       g_string_append_printf (expected, "gpm-%s-000;", kind_str);
-      g_string_append_printf (expected, "%s-caution-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-caution-panel;", kind_str);
       g_string_append_printf (expected, "%s-caution", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -439,9 +458,10 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_DISCHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 95.0,
                    NULL);
+      g_string_append_printf (expected, "%s-100-panel;", kind_str);
       g_string_append_printf (expected, "%s-100;", kind_str);
       g_string_append_printf (expected, "gpm-%s-100;", kind_str);
-      g_string_append_printf (expected, "%s-full-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-panel;", kind_str);
       g_string_append_printf (expected, "%s-full", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -451,11 +471,13 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_DISCHARGING,
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 85.0,
                        NULL);
+      g_string_append_printf (expected, "%s-090-panel;", kind_str);
       g_string_append_printf (expected, "%s-090;", kind_str);
       g_string_append_printf (expected, "gpm-%s-090;", kind_str);
+      g_string_append_printf (expected, "%s-080-panel;", kind_str);
       g_string_append_printf (expected, "%s-080;", kind_str);
       g_string_append_printf (expected, "gpm-%s-080;", kind_str);
-      g_string_append_printf (expected, "%s-full-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-full-panel;", kind_str);
       g_string_append_printf (expected, "%s-full", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -466,11 +488,13 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 50.0,
                        INDICATOR_POWER_DEVICE_TIME, guint64(60*60),
                        NULL);
+      g_string_append_printf (expected, "%s-050-panel;", kind_str);
       g_string_append_printf (expected, "%s-050;", kind_str);
       g_string_append_printf (expected, "gpm-%s-050;", kind_str);
+      g_string_append_printf (expected, "%s-060-panel;", kind_str);
       g_string_append_printf (expected, "%s-060;", kind_str);
       g_string_append_printf (expected, "gpm-%s-060;", kind_str);
-      g_string_append_printf (expected, "%s-good-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-good-panel;", kind_str);
       g_string_append_printf (expected, "%s-good", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -481,11 +505,13 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 25.0,
                        INDICATOR_POWER_DEVICE_TIME, guint64(60*60),
                        NULL);
+      g_string_append_printf (expected, "%s-030-panel;", kind_str);
       g_string_append_printf (expected, "%s-030;", kind_str);
       g_string_append_printf (expected, "gpm-%s-030;", kind_str);
+      g_string_append_printf (expected, "%s-040-panel;", kind_str);
       g_string_append_printf (expected, "%s-040;", kind_str);
       g_string_append_printf (expected, "gpm-%s-040;", kind_str);
-      g_string_append_printf (expected, "%s-low-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-low-panel;", kind_str);
       g_string_append_printf (expected, "%s-low", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -496,11 +522,13 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 25.0,
                        INDICATOR_POWER_DEVICE_TIME, guint64(60*15),
                        NULL);
+      g_string_append_printf (expected, "%s-030-panel;", kind_str);
       g_string_append_printf (expected, "%s-030;", kind_str);
       g_string_append_printf (expected, "gpm-%s-030;", kind_str);
+      g_string_append_printf (expected, "%s-040-panel;", kind_str);
       g_string_append_printf (expected, "%s-040;", kind_str);
       g_string_append_printf (expected, "gpm-%s-040;", kind_str);
-      g_string_append_printf (expected, "%s-low-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-low-panel;", kind_str);
       g_string_append_printf (expected, "%s-low", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -511,11 +539,13 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 5.0,
                        INDICATOR_POWER_DEVICE_TIME, guint64(60*60),
                    NULL);
+      g_string_append_printf (expected, "%s-010-panel;", kind_str);
       g_string_append_printf (expected, "%s-010;", kind_str);
       g_string_append_printf (expected, "gpm-%s-010;", kind_str);
+      g_string_append_printf (expected, "%s-000-panel;", kind_str);
       g_string_append_printf (expected, "%s-000;", kind_str);
       g_string_append_printf (expected, "gpm-%s-000;", kind_str);
-      g_string_append_printf (expected, "%s-caution-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-caution-panel;", kind_str);
       g_string_append_printf (expected, "%s-caution", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
       g_string_truncate (expected, 0);
@@ -526,16 +556,18 @@ TEST_F(DeviceTest, IconNames)
                        INDICATOR_POWER_DEVICE_PERCENTAGE, 5.0,
                        INDICATOR_POWER_DEVICE_TIME, guint64(60*15),
                        NULL);
+      g_string_append_printf (expected, "%s-010-panel;", kind_str);
       g_string_append_printf (expected, "%s-010;", kind_str);
       g_string_append_printf (expected, "gpm-%s-010;", kind_str);
+      g_string_append_printf (expected, "%s-000-panel;", kind_str);
       g_string_append_printf (expected, "%s-000;", kind_str);
       g_string_append_printf (expected, "gpm-%s-000;", kind_str);
-      g_string_append_printf (expected, "%s-caution-symbolic;", kind_str);
+      g_string_append_printf (expected, "%s-caution-panel;", kind_str);
       g_string_append_printf (expected, "%s-caution", kind_str);
       EXPECT_ICON_NAMES_EQ(expected->str, device);
 
       // if we know the charge level, but not that it’s charging,
-      // then we should use the same icons as when it’s discharging. 
+      // then we should use the same icons as when it’s discharging.
       // https://wiki.ubuntu.com/Power?action=diff&rev2=78&rev1=77
       // https://bugs.launchpad.net/ubuntu/+source/indicator-power/+bug/1470080
       g_object_set (o, INDICATOR_POWER_DEVICE_STATE, UP_DEVICE_STATE_UNKNOWN,
@@ -949,7 +981,7 @@ TEST_F(DeviceTest, ChoosePrimary)
       { "phone unknown 0m 61% phone01 1" }
     }
   };
-  
+
   for(const auto& test : tests)
   {
     // build the device list
